"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_device_system_stats_api import RealTimeMonitoringDeviceSystemStatsApi  # noqa: E501


class TestRealTimeMonitoringDeviceSystemStatsApi(unittest.TestCase):
    """RealTimeMonitoringDeviceSystemStatsApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringDeviceSystemStatsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_device_system_cpu_stat(self):
        """Test case for create_device_system_cpu_stat

        """
        pass

    def test_create_device_system_memory_stat(self):
        """Test case for create_device_system_memory_stat

        """
        pass

    def test_get_aggregation_data_by_query16(self):
        """Test case for get_aggregation_data_by_query16

        """
        pass

    def test_get_count18(self):
        """Test case for get_count18

        """
        pass

    def test_get_count_post18(self):
        """Test case for get_count_post18

        """
        pass

    def test_get_post_aggregation_app_data_by_query15(self):
        """Test case for get_post_aggregation_app_data_by_query15

        """
        pass

    def test_get_post_aggregation_data_by_query15(self):
        """Test case for get_post_aggregation_data_by_query15

        """
        pass

    def test_get_post_stat_bulk_raw_data16(self):
        """Test case for get_post_stat_bulk_raw_data16

        """
        pass

    def test_get_stat_bulk_raw_data16(self):
        """Test case for get_stat_bulk_raw_data16

        """
        pass

    def test_get_stat_data_fields18(self):
        """Test case for get_stat_data_fields18

        """
        pass

    def test_get_stat_data_raw_data15(self):
        """Test case for get_stat_data_raw_data15

        """
        pass

    def test_get_stat_data_raw_data_as_csv16(self):
        """Test case for get_stat_data_raw_data_as_csv16

        """
        pass

    def test_get_stat_query_fields18(self):
        """Test case for get_stat_query_fields18

        """
        pass

    def test_get_stats_raw_data16(self):
        """Test case for get_stats_raw_data16

        """
        pass


if __name__ == '__main__':
    unittest.main()
