"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_ips_alert_api import MonitoringIPsAlertApi  # noqa: E501


class TestMonitoringIPsAlertApi(unittest.TestCase):
    """MonitoringIPsAlertApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringIPsAlertApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_by_query21(self):
        """Test case for get_aggregation_data_by_query21

        """
        pass

    def test_get_count23(self):
        """Test case for get_count23

        """
        pass

    def test_get_count_post23(self):
        """Test case for get_count_post23

        """
        pass

    def test_get_post_aggregation_app_data_by_query20(self):
        """Test case for get_post_aggregation_app_data_by_query20

        """
        pass

    def test_get_post_aggregation_data_by_query20(self):
        """Test case for get_post_aggregation_data_by_query20

        """
        pass

    def test_get_post_stat_bulk_raw_data21(self):
        """Test case for get_post_stat_bulk_raw_data21

        """
        pass

    def test_get_stat_bulk_raw_data21(self):
        """Test case for get_stat_bulk_raw_data21

        """
        pass

    def test_get_stat_data_fields23(self):
        """Test case for get_stat_data_fields23

        """
        pass

    def test_get_stat_data_raw_data20(self):
        """Test case for get_stat_data_raw_data20

        """
        pass

    def test_get_stat_data_raw_data_as_csv21(self):
        """Test case for get_stat_data_raw_data_as_csv21

        """
        pass

    def test_get_stat_query_fields23(self):
        """Test case for get_stat_query_fields23

        """
        pass

    def test_get_stats_raw_data21(self):
        """Test case for get_stats_raw_data21

        """
        pass


if __name__ == '__main__':
    unittest.main()
