"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_template_configuration_api import ConfigurationTemplateConfigurationApi  # noqa: E501


class TestConfigurationTemplateConfigurationApi(unittest.TestCase):
    """ConfigurationTemplateConfigurationApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationTemplateConfigurationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_cli_mode_devices(self):
        """Test case for generate_cli_mode_devices

        """
        pass

    def test_generatev_manage_mode_devices(self):
        """Test case for generatev_manage_mode_devices

        """
        pass

    def test_get_attached_config(self):
        """Test case for get_attached_config

        """
        pass

    def test_get_compatible_devices(self):
        """Test case for get_compatible_devices

        """
        pass

    def test_get_device_diff(self):
        """Test case for get_device_diff

        """
        pass

    def test_get_running_config(self):
        """Test case for get_running_config

        """
        pass

    def test_get_vpn_for_device(self):
        """Test case for get_vpn_for_device

        """
        pass

    def test_rma_update(self):
        """Test case for rma_update

        """
        pass

    def test_update_device_to_cli_mode(self):
        """Test case for update_device_to_cli_mode

        """
        pass

    def test_upload_config(self):
        """Test case for upload_config

        """
        pass


if __name__ == '__main__':
    unittest.main()
