"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.data_collection_agent_api import DataCollectionAgentApi  # noqa: E501


class TestDataCollectionAgentApi(unittest.TestCase):
    """DataCollectionAgentApi unit test stubs"""

    def setUp(self):
        self.api = DataCollectionAgentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dca_analytics_data_file(self):
        """Test case for create_dca_analytics_data_file

        """
        pass

    def test_create_stats(self):
        """Test case for create_stats

        """
        pass

    def test_generate_alarm(self):
        """Test case for generate_alarm

        """
        pass

    def test_generate_dca_device_state_data(self):
        """Test case for generate_dca_device_state_data

        """
        pass

    def test_generate_dca_device_statistics_data(self):
        """Test case for generate_dca_device_statistics_data

        """
        pass

    def test_get_access_token(self):
        """Test case for get_access_token

        """
        pass

    def test_get_all_stats_data_dca(self):
        """Test case for get_all_stats_data_dca

        """
        pass

    def test_get_cloud_services_configuration_dca(self):
        """Test case for get_cloud_services_configuration_dca

        """
        pass

    def test_get_crash_logs(self):
        """Test case for get_crash_logs

        """
        pass

    def test_get_crash_logs_synced(self):
        """Test case for get_crash_logs_synced

        """
        pass

    def test_get_dca_attached_config_to_device(self):
        """Test case for get_dca_attached_config_to_device

        """
        pass

    def test_get_dca_tenant_owners(self):
        """Test case for get_dca_tenant_owners

        """
        pass

    def test_get_devices_details_dca(self):
        """Test case for get_devices_details_dca

        """
        pass

    def test_get_id_token(self):
        """Test case for get_id_token

        """
        pass

    def test_get_stats_db_index_status(self):
        """Test case for get_stats_db_index_status

        """
        pass

    def test_get_telemetry_settings(self):
        """Test case for get_telemetry_settings

        """
        pass

    def test_get_template_policy_definitions_dca(self):
        """Test case for get_template_policy_definitions_dca

        """
        pass

    def test_get_vedge_template_list_dca(self):
        """Test case for get_vedge_template_list_dca

        """
        pass

    def test_get_vpn_lists_dca(self):
        """Test case for get_vpn_lists_dca

        """
        pass

    def test_get_vsmart_template_list_dca(self):
        """Test case for get_vsmart_template_list_dca

        """
        pass

    def test_list_all_devices_dca(self):
        """Test case for list_all_devices_dca

        """
        pass

    def test_store_access_token(self):
        """Test case for store_access_token

        """
        pass

    def test_store_id_token(self):
        """Test case for store_id_token

        """
        pass


if __name__ == '__main__':
    unittest.main()
