"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_dpi_api import MonitoringDPIApi  # noqa: E501


class TestMonitoringDPIApi(unittest.TestCase):
    """MonitoringDPIApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringDPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dpi_device_and_app_details(self):
        """Test case for create_dpi_device_and_app_details

        """
        pass

    def test_create_dpi_device_grid_data(self):
        """Test case for create_dpi_device_grid_data

        """
        pass

    def test_create_dpi_flows_grid_list_query(self):
        """Test case for create_dpi_flows_grid_list_query

        """
        pass

    def test_create_dpi_summary(self):
        """Test case for create_dpi_summary

        """
        pass

    def test_get_aggregation_data_by_query12(self):
        """Test case for get_aggregation_data_by_query12

        """
        pass

    def test_get_aggregation_data_dpi(self):
        """Test case for get_aggregation_data_dpi

        """
        pass

    def test_get_aggregation_data_for_packet_dup(self):
        """Test case for get_aggregation_data_for_packet_dup

        """
        pass

    def test_get_count14(self):
        """Test case for get_count14

        """
        pass

    def test_get_count_post14(self):
        """Test case for get_count_post14

        """
        pass

    def test_get_post_aggregation_app_data(self):
        """Test case for get_post_aggregation_app_data

        """
        pass

    def test_get_post_aggregation_data(self):
        """Test case for get_post_aggregation_data

        """
        pass

    def test_get_post_stat_bulk_raw_data12(self):
        """Test case for get_post_stat_bulk_raw_data12

        """
        pass

    def test_get_stat_bulk_raw_data12(self):
        """Test case for get_stat_bulk_raw_data12

        """
        pass

    def test_get_stat_data_fields14(self):
        """Test case for get_stat_data_fields14

        """
        pass

    def test_get_stat_data_raw_data12(self):
        """Test case for get_stat_data_raw_data12

        """
        pass

    def test_get_stat_data_raw_data_as_csv12(self):
        """Test case for get_stat_data_raw_data_as_csv12

        """
        pass

    def test_get_stat_query_fields14(self):
        """Test case for get_stat_query_fields14

        """
        pass

    def test_get_stats_raw_data12(self):
        """Test case for get_stats_raw_data12

        """
        pass

    def test_get_unique_flow_count(self):
        """Test case for get_unique_flow_count

        """
        pass


if __name__ == '__main__':
    unittest.main()
