"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_bfd_api import RealTimeMonitoringBFDApi  # noqa: E501


class TestRealTimeMonitoringBFDApi(unittest.TestCase):
    """RealTimeMonitoringBFDApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringBFDApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bfd_history_list(self):
        """Test case for create_bfd_history_list

        """
        pass

    def test_create_bfd_link_list(self):
        """Test case for create_bfd_link_list

        """
        pass

    def test_create_bfd_sessions(self):
        """Test case for create_bfd_sessions

        """
        pass

    def test_create_bfd_summary(self):
        """Test case for create_bfd_summary

        """
        pass

    def test_create_synced_bfd_session(self):
        """Test case for create_synced_bfd_session

        """
        pass

    def test_create_tloc_summary(self):
        """Test case for create_tloc_summary

        """
        pass

    def test_get_bfd_site_state_detail(self):
        """Test case for get_bfd_site_state_detail

        """
        pass

    def test_get_bfd_sites_summary(self):
        """Test case for get_bfd_sites_summary

        """
        pass

    def test_get_device_bfd_state_summary(self):
        """Test case for get_device_bfd_state_summary

        """
        pass

    def test_get_device_bfd_state_summary_tloc(self):
        """Test case for get_device_bfd_state_summary_tloc

        """
        pass

    def test_get_device_bfd_status(self):
        """Test case for get_device_bfd_status

        """
        pass

    def test_get_device_bfd_status_summary(self):
        """Test case for get_device_bfd_status_summary

        """
        pass


if __name__ == '__main__':
    unittest.main()
