"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_policy_api import RealTimeMonitoringPolicyApi  # noqa: E501


class TestRealTimeMonitoringPolicyApi(unittest.TestCase):
    """RealTimeMonitoringPolicyApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringPolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_polic_data_policy_filter(self):
        """Test case for create_polic_data_policy_filter

        """
        pass

    def test_create_polic_qos_map_info(self):
        """Test case for create_polic_qos_map_info

        """
        pass

    def test_create_polic_qos_scheduler_info(self):
        """Test case for create_polic_qos_scheduler_info

        """
        pass

    def test_create_policy_access_list_associations(self):
        """Test case for create_policy_access_list_associations

        """
        pass

    def test_create_policy_access_list_associations_ipv6(self):
        """Test case for create_policy_access_list_associations_ipv6

        """
        pass

    def test_create_policy_access_list_counters(self):
        """Test case for create_policy_access_list_counters

        """
        pass

    def test_create_policy_access_list_counters_ipv6(self):
        """Test case for create_policy_access_list_counters_ipv6

        """
        pass

    def test_create_policy_access_list_names(self):
        """Test case for create_policy_access_list_names

        """
        pass

    def test_create_policy_access_list_names_ipv6(self):
        """Test case for create_policy_access_list_names_ipv6

        """
        pass

    def test_create_policy_access_list_policers(self):
        """Test case for create_policy_access_list_policers

        """
        pass

    def test_create_policy_access_list_policers_ipv6(self):
        """Test case for create_policy_access_list_policers_ipv6

        """
        pass

    def test_create_policy_app_route_policy_filter(self):
        """Test case for create_policy_app_route_policy_filter

        """
        pass

    def test_create_policy_filter_memory_usage(self):
        """Test case for create_policy_filter_memory_usage

        """
        pass

    def test_create_policy_rewrite_associations_info(self):
        """Test case for create_policy_rewrite_associations_info

        """
        pass

    def test_get_zbfw_statistics(self):
        """Test case for get_zbfw_statistics

        """
        pass

    def test_get_zone_drop_statistics(self):
        """Test case for get_zone_drop_statistics

        """
        pass

    def test_get_zone_pair_sessions(self):
        """Test case for get_zone_pair_sessions

        """
        pass

    def test_get_zone_pairs(self):
        """Test case for get_zone_pairs

        """
        pass

    def test_get_zone_policy_filters(self):
        """Test case for get_zone_policy_filters

        """
        pass

    def test_show_sdwan_policy_from_vsmart(self):
        """Test case for show_sdwan_policy_from_vsmart

        """
        pass


if __name__ == '__main__':
    unittest.main()
