"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.certificate_management_v_manage_api import CertificateManagementVManageApi  # noqa: E501


class TestCertificateManagementVManageApi(unittest.TestCase):
    """CertificateManagementVManageApi unit test stubs"""

    def setUp(self):
        self.api = CertificateManagementVManageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_dump_certificate(self):
        """Test case for dump_certificate

        """
        pass

    def test_get_certificate(self):
        """Test case for get_certificate

        """
        pass

    def test_get_csr(self):
        """Test case for get_csr

        """
        pass

    def test_import_certificate(self):
        """Test case for import_certificate

        """
        pass

    def test_rollback(self):
        """Test case for rollback

        """
        pass

    def test_show_info(self):
        """Test case for show_info

        """
        pass


if __name__ == '__main__':
    unittest.main()
