"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.tag_api import TagApi  # noqa: E501


class TestTagApi(unittest.TestCase):
    """TagApi unit test stubs"""

    def setUp(self):
        self.api = TagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check_for_conflicts_when_tagging(self):
        """Test case for check_for_conflicts_when_tagging

        """
        pass

    def test_check_rules(self):
        """Test case for check_rules

        """
        pass

    def test_create_tag(self):
        """Test case for create_tag

        """
        pass

    def test_create_tag_rule(self):
        """Test case for create_tag_rule

        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        """
        pass

    def test_delete_tag_rule(self):
        """Test case for delete_tag_rule

        """
        pass

    def test_edit_tag_rule(self):
        """Test case for edit_tag_rule

        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        """
        pass

    def test_get_tag_rules(self):
        """Test case for get_tag_rules

        """
        pass

    def test_reindex_tag(self):
        """Test case for reindex_tag

        """
        pass


if __name__ == '__main__':
    unittest.main()
