"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_cflowd_flows_api import MonitoringCflowdFlowsApi  # noqa: E501


class TestMonitoringCflowdFlowsApi(unittest.TestCase):
    """MonitoringCflowdFlowsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringCflowdFlowsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cflow_collector_list(self):
        """Test case for create_cflow_collector_list

        """
        pass

    def test_create_cflowd_collector_list(self):
        """Test case for create_cflowd_collector_list

        """
        pass

    def test_create_cflowd_flows_count_list(self):
        """Test case for create_cflowd_flows_count_list

        """
        pass

    def test_create_cflowd_statistics(self):
        """Test case for create_cflowd_statistics

        """
        pass

    def test_create_cflowd_template(self):
        """Test case for create_cflowd_template

        """
        pass

    def test_get_cflowd_dpi_device_field_json(self):
        """Test case for get_cflowd_dpi_device_field_json

        """
        pass

    def test_get_cflowd_dpi_field_json(self):
        """Test case for get_cflowd_dpi_field_json

        """
        pass

    def test_get_fn_f_cache_stats(self):
        """Test case for get_fn_f_cache_stats

        """
        pass

    def test_get_fn_f_export_client_stats(self):
        """Test case for get_fn_f_export_client_stats

        """
        pass

    def test_get_fn_f_export_stats(self):
        """Test case for get_fn_f_export_stats

        """
        pass

    def test_get_fn_f_monitor_stats(self):
        """Test case for get_fn_f_monitor_stats

        """
        pass

    def test_get_fnf(self):
        """Test case for get_fnf

        """
        pass


if __name__ == '__main__':
    unittest.main()
