"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_i_psec_api import RealTimeMonitoringIPsecApi  # noqa: E501


class TestRealTimeMonitoringIPsecApi(unittest.TestCase):
    """RealTimeMonitoringIPsecApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringIPsecApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_crypto_ipsec_identity(self):
        """Test case for create_crypto_ipsec_identity

        """
        pass

    def test_create_cryptov1_local_sa_list(self):
        """Test case for create_cryptov1_local_sa_list

        """
        pass

    def test_create_cryptov2_local_sa_list(self):
        """Test case for create_cryptov2_local_sa_list

        """
        pass

    def test_create_i_psec_pwk_inbound_connections(self):
        """Test case for create_i_psec_pwk_inbound_connections

        """
        pass

    def test_create_i_psec_pwk_local_sa(self):
        """Test case for create_i_psec_pwk_local_sa

        """
        pass

    def test_create_i_psec_pwk_outbound_connections(self):
        """Test case for create_i_psec_pwk_outbound_connections

        """
        pass

    def test_create_ike_inbound_list(self):
        """Test case for create_ike_inbound_list

        """
        pass

    def test_create_ike_outbound_list(self):
        """Test case for create_ike_outbound_list

        """
        pass

    def test_create_ike_sessions(self):
        """Test case for create_ike_sessions

        """
        pass

    def test_create_in_bound_list(self):
        """Test case for create_in_bound_list

        """
        pass

    def test_create_local_sa_list(self):
        """Test case for create_local_sa_list

        """
        pass

    def test_create_out_bound_list(self):
        """Test case for create_out_bound_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
