"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_trustsec_api import RealTimeMonitoringTrustsecApi  # noqa: E501


class TestRealTimeMonitoringTrustsecApi(unittest.TestCase):
    """RealTimeMonitoringTrustsecApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringTrustsecApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_cts_pac(self):
        """Test case for get_cts_pac

        """
        pass

    def test_get_environment_data(self):
        """Test case for get_environment_data

        """
        pass

    def test_get_radius_server(self):
        """Test case for get_radius_server

        """
        pass

    def test_get_role_based_counters(self):
        """Test case for get_role_based_counters

        """
        pass

    def test_get_role_based_ipv6_counters(self):
        """Test case for get_role_based_ipv6_counters

        """
        pass

    def test_get_role_based_ipv6_permissions(self):
        """Test case for get_role_based_ipv6_permissions

        """
        pass

    def test_get_role_based_permissions(self):
        """Test case for get_role_based_permissions

        """
        pass

    def test_get_role_based_sgt_map(self):
        """Test case for get_role_based_sgt_map

        """
        pass

    def test_get_sxp_connections(self):
        """Test case for get_sxp_connections

        """
        pass


if __name__ == '__main__':
    unittest.main()
