"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tier(self):
        """Test case for add_tier

        """
        pass

    def test_delete_tier(self):
        """Test case for delete_tier

        """
        pass

    def test_get_o365_preferred_path_from_v_analytics(self):
        """Test case for get_o365_preferred_path_from_v_analytics

        """
        pass

    def test_get_tiers(self):
        """Test case for get_tiers

        """
        pass

    def test_update_device_action_status(self):
        """Test case for update_device_action_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
