"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_omp_api import RealTimeMonitoringOMPApi  # noqa: E501


class TestRealTimeMonitoringOMPApi(unittest.TestCase):
    """RealTimeMonitoringOMPApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringOMPApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_advertised_routes_list(self):
        """Test case for create_advertised_routes_list

        """
        pass

    def test_create_advertised_routes_list_ipv6(self):
        """Test case for create_advertised_routes_list_ipv6

        """
        pass

    def test_create_advertised_tlocs_list(self):
        """Test case for create_advertised_tlocs_list

        """
        pass

    def test_create_omp_cloud_x_recv(self):
        """Test case for create_omp_cloud_x_recv

        """
        pass

    def test_create_omp_link_list(self):
        """Test case for create_omp_link_list

        """
        pass

    def test_create_omp_mcast_auto_discover_advt(self):
        """Test case for create_omp_mcast_auto_discover_advt

        """
        pass

    def test_create_omp_mcast_auto_discover_recv(self):
        """Test case for create_omp_mcast_auto_discover_recv

        """
        pass

    def test_create_omp_mcast_routes_advt(self):
        """Test case for create_omp_mcast_routes_advt

        """
        pass

    def test_create_omp_mcast_routes_recv(self):
        """Test case for create_omp_mcast_routes_recv

        """
        pass

    def test_create_omp_services(self):
        """Test case for create_omp_services

        """
        pass

    def test_create_omp_session_list(self):
        """Test case for create_omp_session_list

        """
        pass

    def test_create_omp_summary(self):
        """Test case for create_omp_summary

        """
        pass

    def test_create_received_routes_list(self):
        """Test case for create_received_routes_list

        """
        pass

    def test_create_received_routes_list_ipv6(self):
        """Test case for create_received_routes_list_ipv6

        """
        pass

    def test_create_received_tlocs_list(self):
        """Test case for create_received_tlocs_list

        """
        pass

    def test_create_synced_omp_session_list(self):
        """Test case for create_synced_omp_session_list

        """
        pass

    def test_get_device_omp_status(self):
        """Test case for get_device_omp_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
