"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_device_control_api import RealTimeMonitoringDeviceControlApi  # noqa: E501


class TestRealTimeMonitoringDeviceControlApi(unittest.TestCase):
    """RealTimeMonitoringDeviceControlApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringDeviceControlApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_connection_history_list_real_time(self):
        """Test case for create_connection_history_list_real_time

        """
        pass

    def test_create_connections_summary(self):
        """Test case for create_connections_summary

        """
        pass

    def test_create_link_list(self):
        """Test case for create_link_list

        """
        pass

    def test_create_local_properties_list_list_real_t_ime(self):
        """Test case for create_local_properties_list_list_real_t_ime

        """
        pass

    def test_create_local_properties_synced_list(self):
        """Test case for create_local_properties_synced_list

        """
        pass

    def test_create_real_time_connection_list(self):
        """Test case for create_real_time_connection_list

        """
        pass

    def test_create_synced_connection_list(self):
        """Test case for create_synced_connection_list

        """
        pass

    def test_create_valid_devices_list_real_time(self):
        """Test case for create_valid_devices_list_real_time

        """
        pass

    def test_create_valid_v_smarts_list_real_time(self):
        """Test case for create_valid_v_smarts_list_real_time

        """
        pass

    def test_create_wan_interface_list_list(self):
        """Test case for create_wan_interface_list_list

        """
        pass

    def test_create_wan_interface_synced_list(self):
        """Test case for create_wan_interface_synced_list

        """
        pass

    def test_get_affinity_config(self):
        """Test case for get_affinity_config

        """
        pass

    def test_get_affinity_status(self):
        """Test case for get_affinity_status

        """
        pass

    def test_get_connection_statistics(self):
        """Test case for get_connection_statistics

        """
        pass

    def test_get_device_control_status_summary(self):
        """Test case for get_device_control_status_summary

        """
        pass

    def test_get_local_device_status(self):
        """Test case for get_local_device_status

        """
        pass

    def test_get_port_hop_color(self):
        """Test case for get_port_hop_color

        """
        pass

    def test_get_total_count_for_device_states(self):
        """Test case for get_total_count_for_device_states

        """
        pass

    def test_get_valid_v_manage_id_real_time(self):
        """Test case for get_valid_v_manage_id_real_time

        """
        pass

    def test_network_summary(self):
        """Test case for network_summary

        """
        pass


if __name__ == '__main__':
    unittest.main()
