"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.deployment_mode_api import DeploymentModeApi  # noqa: E501


class TestDeploymentModeApi(unittest.TestCase):
    """DeploymentModeApi unit test stubs"""

    def setUp(self):
        self.api = DeploymentModeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_config_fedramp_mode(self):
        """Test case for config_fedramp_mode

        """
        pass

    def test_configure_dns_sec(self):
        """Test case for configure_dns_sec

        """
        pass

    def test_configure_wazuh_client(self):
        """Test case for configure_wazuh_client

        """
        pass

    def test_get_dns_sec_status(self):
        """Test case for get_dns_sec_status

        """
        pass

    def test_get_wazuh_agent_status(self):
        """Test case for get_wazuh_agent_status

        """
        pass

    def test_reques_dns_sec_actions(self):
        """Test case for reques_dns_sec_actions

        """
        pass

    def test_request_wazuh_actions(self):
        """Test case for request_wazuh_actions

        """
        pass


if __name__ == '__main__':
    unittest.main()
