"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_app_hosting_api import RealTimeMonitoringAppHostingApi  # noqa: E501


class TestRealTimeMonitoringAppHostingApi(unittest.TestCase):
    """RealTimeMonitoringAppHostingApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringAppHostingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_app_hosting_attached_devices(self):
        """Test case for get_app_hosting_attached_devices

        """
        pass

    def test_get_app_hosting_details(self):
        """Test case for get_app_hosting_details

        """
        pass

    def test_get_app_hosting_guest_routes(self):
        """Test case for get_app_hosting_guest_routes

        """
        pass

    def test_get_app_hosting_network_devices(self):
        """Test case for get_app_hosting_network_devices

        """
        pass

    def test_get_app_hosting_network_utils(self):
        """Test case for get_app_hosting_network_utils

        """
        pass

    def test_get_app_hosting_processes(self):
        """Test case for get_app_hosting_processes

        """
        pass

    def test_get_app_hosting_storage_utils(self):
        """Test case for get_app_hosting_storage_utils

        """
        pass

    def test_get_app_hosting_utilization(self):
        """Test case for get_app_hosting_utilization

        """
        pass


if __name__ == '__main__':
    unittest.main()
