"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_cloud_on_ramp_api import ConfigurationCloudOnRampApi  # noqa: E501


class TestConfigurationCloudOnRampApi(unittest.TestCase):
    """ConfigurationCloudOnRampApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationCloudOnRampApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acquire_resource_pool(self):
        """Test case for acquire_resource_pool

        """
        pass

    def test_add_device_pair(self):
        """Test case for add_device_pair

        """
        pass

    def test_add_transit_vpc(self):
        """Test case for add_transit_vpc

        """
        pass

    def test_authenticate_cloud_on_ramp_cred_and_add(self):
        """Test case for authenticate_cloud_on_ramp_cred_and_add

        """
        pass

    def test_authenticate_cred_and_update(self):
        """Test case for authenticate_cred_and_update

        """
        pass

    def test_create_and_map(self):
        """Test case for create_and_map

        """
        pass

    def test_create_resource_pool(self):
        """Test case for create_resource_pool

        """
        pass

    def test_get_ami_list(self):
        """Test case for get_ami_list

        """
        pass

    def test_get_cloud_accounts(self):
        """Test case for get_cloud_accounts

        """
        pass

    def test_get_cloud_host_vpc_account_details(self):
        """Test case for get_cloud_host_vpc_account_details

        """
        pass

    def test_get_cloud_host_vpcs(self):
        """Test case for get_cloud_host_vpcs

        """
        pass

    def test_get_cloud_list(self):
        """Test case for get_cloud_list

        """
        pass

    def test_get_cloud_mapped_host_accounts(self):
        """Test case for get_cloud_mapped_host_accounts

        """
        pass

    def test_get_cloud_on_ramp_devices(self):
        """Test case for get_cloud_on_ramp_devices

        """
        pass

    def test_get_cor_status(self):
        """Test case for get_cor_status

        """
        pass

    def test_get_external_id(self):
        """Test case for get_external_id

        """
        pass

    def test_get_host_vpcs(self):
        """Test case for get_host_vpcs

        """
        pass

    def test_get_mapped_vpcs(self):
        """Test case for get_mapped_vpcs

        """
        pass

    def test_get_pem_key_list(self):
        """Test case for get_pem_key_list

        """
        pass

    def test_get_tenant_and_host_vpc_list(self):
        """Test case for get_tenant_and_host_vpc_list

        """
        pass

    def test_get_transit_device_pair_and_host_list(self):
        """Test case for get_transit_device_pair_and_host_list

        """
        pass

    def test_get_transit_vpc_supported_size(self):
        """Test case for get_transit_vpc_supported_size

        """
        pass

    def test_get_transit_vpc_vpn_list(self):
        """Test case for get_transit_vpc_vpn_list

        """
        pass

    def test_get_transit_vpcs(self):
        """Test case for get_transit_vpcs

        """
        pass

    def test_map_vpcs(self):
        """Test case for map_vpcs

        """
        pass

    def test_raise_alarm_for_account(self):
        """Test case for raise_alarm_for_account

        """
        pass

    def test_remove_device_id(self):
        """Test case for remove_device_id

        """
        pass

    def test_remove_transit_vpc(self):
        """Test case for remove_transit_vpc

        """
        pass

    def test_scale_down(self):
        """Test case for scale_down

        """
        pass

    def test_scale_up(self):
        """Test case for scale_up

        """
        pass

    def test_unmap_vpcs(self):
        """Test case for unmap_vpcs

        """
        pass

    def test_update_host_vpc_reachability(self):
        """Test case for update_host_vpc_reachability

        """
        pass

    def test_update_transit_vpc(self):
        """Test case for update_transit_vpc

        """
        pass

    def test_update_transit_vpc_autoscale_properties(self):
        """Test case for update_transit_vpc_autoscale_properties

        """
        pass

    def test_updatestatus(self):
        """Test case for updatestatus

        """
        pass


if __name__ == '__main__':
    unittest.main()
