"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_network_design_templates_api import ConfigurationNetworkDesignTemplatesApi  # noqa: E501


class TestConfigurationNetworkDesignTemplatesApi(unittest.TestCase):
    """ConfigurationNetworkDesignTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationNetworkDesignTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_device_profile_template(self):
        """Test case for edit_device_profile_template

        """
        pass

    def test_edit_global_template(self):
        """Test case for edit_global_template

        """
        pass

    def test_generate_profile_template_list(self):
        """Test case for generate_profile_template_list

        """
        pass

    def test_get_device_profile_feature_template_list(self):
        """Test case for get_device_profile_feature_template_list

        """
        pass

    def test_get_device_profile_template(self):
        """Test case for get_device_profile_template

        """
        pass

    def test_get_global_template(self):
        """Test case for get_global_template

        """
        pass


if __name__ == '__main__':
    unittest.main()
