"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_hardware_api import RealTimeMonitoringHardwareApi  # noqa: E501


class TestRealTimeMonitoringHardwareApi(unittest.TestCase):
    """RealTimeMonitoringHardwareApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringHardwareApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_alarm_list(self):
        """Test case for create_alarm_list

        """
        pass

    def test_create_environment_list(self):
        """Test case for create_environment_list

        """
        pass

    def test_create_error_alarm_list(self):
        """Test case for create_error_alarm_list

        """
        pass

    def test_create_inventory_list(self):
        """Test case for create_inventory_list

        """
        pass

    def test_create_status_summary(self):
        """Test case for create_status_summary

        """
        pass

    def test_create_synced_alarm_list(self):
        """Test case for create_synced_alarm_list

        """
        pass

    def test_create_synced_environment_list(self):
        """Test case for create_synced_environment_list

        """
        pass

    def test_create_synced_inventory_list(self):
        """Test case for create_synced_inventory_list

        """
        pass

    def test_create_system_list(self):
        """Test case for create_system_list

        """
        pass

    def test_create_temp_threshold_list(self):
        """Test case for create_temp_threshold_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
