"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_events_api import MonitoringEventsApi  # noqa: E501


class TestMonitoringEventsApi(unittest.TestCase):
    """MonitoringEventsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringEventsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_events_query_config(self):
        """Test case for create_events_query_config

        """
        pass

    def test_enable_events_from_file(self):
        """Test case for enable_events_from_file

        """
        pass

    def test_find_events(self):
        """Test case for find_events

        """
        pass

    def test_get_aggregation_data_by_query25(self):
        """Test case for get_aggregation_data_by_query25

        """
        pass

    def test_get_components_as_key_value(self):
        """Test case for get_components_as_key_value

        """
        pass

    def test_get_count27(self):
        """Test case for get_count27

        """
        pass

    def test_get_count_post27(self):
        """Test case for get_count_post27

        """
        pass

    def test_get_event_types_as_key_value(self):
        """Test case for get_event_types_as_key_value

        """
        pass

    def test_get_listeners_info(self):
        """Test case for get_listeners_info

        """
        pass

    def test_get_post_aggregation_app_data_by_query24(self):
        """Test case for get_post_aggregation_app_data_by_query24

        """
        pass

    def test_get_post_aggregation_data_by_query24(self):
        """Test case for get_post_aggregation_data_by_query24

        """
        pass

    def test_get_post_stat_bulk_raw_data25(self):
        """Test case for get_post_stat_bulk_raw_data25

        """
        pass

    def test_get_severity_histogram(self):
        """Test case for get_severity_histogram

        """
        pass

    def test_get_stat_bulk_raw_data25(self):
        """Test case for get_stat_bulk_raw_data25

        """
        pass

    def test_get_stat_data_fields27(self):
        """Test case for get_stat_data_fields27

        """
        pass

    def test_get_stat_data_raw_data24(self):
        """Test case for get_stat_data_raw_data24

        """
        pass

    def test_get_stat_data_raw_data_as_csv25(self):
        """Test case for get_stat_data_raw_data_as_csv25

        """
        pass

    def test_get_stat_query_fields27(self):
        """Test case for get_stat_query_fields27

        """
        pass

    def test_get_stats_raw_data25(self):
        """Test case for get_stats_raw_data25

        """
        pass


if __name__ == '__main__':
    unittest.main()
