"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_actions_api import ConfigurationDeviceActionsApi  # noqa: E501


class TestConfigurationDeviceActionsApi(unittest.TestCase):
    """ConfigurationDeviceActionsApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceActionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_filter_vpn_list(self):
        """Test case for create_filter_vpn_list

        """
        pass

    def test_create_unique_vpn_list(self):
        """Test case for create_unique_vpn_list

        """
        pass

    def test_create_vpn_list(self):
        """Test case for create_vpn_list

        """
        pass

    def test_generate_change_partition_info(self):
        """Test case for generate_change_partition_info

        """
        pass

    def test_generate_deactivate_info(self):
        """Test case for generate_deactivate_info

        """
        pass

    def test_generate_device_action_list(self):
        """Test case for generate_device_action_list

        """
        pass

    def test_generate_device_list(self):
        """Test case for generate_device_list

        """
        pass

    def test_generate_install_info(self):
        """Test case for generate_install_info

        """
        pass

    def test_generate_reboot_device_list(self):
        """Test case for generate_reboot_device_list

        """
        pass

    def test_generate_reboot_info(self):
        """Test case for generate_reboot_info

        """
        pass

    def test_generate_rediscover_info(self):
        """Test case for generate_rediscover_info

        """
        pass

    def test_generate_remove_partition_info(self):
        """Test case for generate_remove_partition_info

        """
        pass

    def test_generate_security_devices_list(self):
        """Test case for generate_security_devices_list

        """
        pass

    def test_get_ztp_upgrade_config(self):
        """Test case for get_ztp_upgrade_config

        """
        pass

    def test_get_ztp_upgrade_config_setting(self):
        """Test case for get_ztp_upgrade_config_setting

        """
        pass

    def test_initiate_image_download(self):
        """Test case for initiate_image_download

        """
        pass

    def test_process_amp_api_re_key(self):
        """Test case for process_amp_api_re_key

        """
        pass

    def test_process_change_partition(self):
        """Test case for process_change_partition

        """
        pass

    def test_process_deactivate_smu(self):
        """Test case for process_deactivate_smu

        """
        pass

    def test_process_default_partition(self):
        """Test case for process_default_partition

        """
        pass

    def test_process_delete_amp_api_key(self):
        """Test case for process_delete_amp_api_key

        """
        pass

    def test_process_install(self):
        """Test case for process_install

        """
        pass

    def test_process_lxc_activate(self):
        """Test case for process_lxc_activate

        """
        pass

    def test_process_lxc_delete(self):
        """Test case for process_lxc_delete

        """
        pass

    def test_process_lxc_install(self):
        """Test case for process_lxc_install

        """
        pass

    def test_process_lxc_reload(self):
        """Test case for process_lxc_reload

        """
        pass

    def test_process_lxc_reset(self):
        """Test case for process_lxc_reset

        """
        pass

    def test_process_lxc_upgrade(self):
        """Test case for process_lxc_upgrade

        """
        pass

    def test_process_reboot(self):
        """Test case for process_reboot

        """
        pass

    def test_process_remove_partition(self):
        """Test case for process_remove_partition

        """
        pass

    def test_process_remove_software_image(self):
        """Test case for process_remove_software_image

        """
        pass

    def test_process_vnf_install(self):
        """Test case for process_vnf_install

        """
        pass

    def test_process_ztp_upgrade_config(self):
        """Test case for process_ztp_upgrade_config

        """
        pass

    def test_process_ztp_upgrade_config_setting(self):
        """Test case for process_ztp_upgrade_config_setting

        """
        pass

    def test_re_discover_all_device(self):
        """Test case for re_discover_all_device

        """
        pass

    def test_re_discover_devices(self):
        """Test case for re_discover_devices

        """
        pass

    def test_test_api_key(self):
        """Test case for test_api_key

        """
        pass

    def test_test_iox_config(self):
        """Test case for test_iox_config

        """
        pass

    def test_trigger_pending_tasks_monitoring(self):
        """Test case for trigger_pending_tasks_monitoring

        """
        pass


if __name__ == '__main__':
    unittest.main()
