"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_ssl_proxy_certificate_management_api import ConfigurationDeviceSSLProxyCertificateManagementApi  # noqa: E501


class TestConfigurationDeviceSSLProxyCertificateManagementApi(unittest.TestCase):
    """ConfigurationDeviceSSLProxyCertificateManagementApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceSSLProxyCertificateManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_wan_edge(self):
        """Test case for add_wan_edge

        """
        pass

    def test_generate_ssl_proxy_csr(self):
        """Test case for generate_ssl_proxy_csr

        """
        pass

    def test_generate_ssl_proxy_csr_0(self):
        """Test case for generate_ssl_proxy_csr_0

        """
        pass

    def test_get_all_device_certificates(self):
        """Test case for get_all_device_certificates

        """
        pass

    def test_get_all_device_csr(self):
        """Test case for get_all_device_csr

        """
        pass

    def test_get_certificate_state(self):
        """Test case for get_certificate_state

        """
        pass

    def test_get_enterprise_certificate(self):
        """Test case for get_enterprise_certificate

        """
        pass

    def test_get_proxy_cert_of_edge(self):
        """Test case for get_proxy_cert_of_edge

        """
        pass

    def test_get_self_signed_cert(self):
        """Test case for get_self_signed_cert

        """
        pass

    def test_get_ssl_proxy_csr(self):
        """Test case for get_ssl_proxy_csr

        """
        pass

    def test_get_ssl_proxy_list(self):
        """Test case for get_ssl_proxy_list

        """
        pass

    def test_get_v_manage_enterprise_root_certificate(self):
        """Test case for get_v_manage_enterprise_root_certificate

        """
        pass

    def test_getv_manage_certificate(self):
        """Test case for getv_manage_certificate

        """
        pass

    def test_getv_manage_csr(self):
        """Test case for getv_manage_csr

        """
        pass

    def test_getv_manage_root_ca(self):
        """Test case for getv_manage_root_ca

        """
        pass

    def test_renew_certificate(self):
        """Test case for renew_certificate

        """
        pass

    def test_revoke_certificate(self):
        """Test case for revoke_certificate

        """
        pass

    def test_revoke_renew_certificate(self):
        """Test case for revoke_renew_certificate

        """
        pass

    def test_set_enterprise_cert(self):
        """Test case for set_enterprise_cert

        """
        pass

    def test_set_enterprise_root_ca_cert(self):
        """Test case for set_enterprise_root_ca_cert

        """
        pass

    def test_setv_manage_root_ca(self):
        """Test case for setv_manage_root_ca

        """
        pass

    def test_setv_manageintermediate_cert(self):
        """Test case for setv_manageintermediate_cert

        """
        pass

    def test_update_certificate(self):
        """Test case for update_certificate

        """
        pass

    def test_upload_certificiates(self):
        """Test case for upload_certificiates

        """
        pass


if __name__ == '__main__':
    unittest.main()
