"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.smart_license_api import SmartLicenseApi  # noqa: E501


class TestSmartLicenseApi(unittest.TestCase):
    """SmartLicenseApi unit test stubs"""

    def setUp(self):
        self.api = SmartLicenseApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_fetch_accounts(self):
        """Test case for fetch_accounts

        """
        pass

    def test_fetch_reports(self):
        """Test case for fetch_reports

        """
        pass

    def test_fetch_reports1(self):
        """Test case for fetch_reports1

        """
        pass

    def test_get_settings(self):
        """Test case for get_settings

        """
        pass

    def test_sleauthenticate(self):
        """Test case for sleauthenticate

        """
        pass

    def test_sync_licenses(self):
        """Test case for sync_licenses

        """
        pass

    def test_sync_licenses1(self):
        """Test case for sync_licenses1

        """
        pass

    def test_upload_ack(self):
        """Test case for upload_ack

        """
        pass


if __name__ == '__main__':
    unittest.main()
