"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.system_cloud_service_api import SystemCloudServiceApi  # noqa: E501


class TestSystemCloudServiceApi(unittest.TestCase):
    """SystemCloudServiceApi unit test stubs"""

    def setUp(self):
        self.api = SystemCloudServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_cloud_credentials(self):
        """Test case for add_cloud_credentials

        """
        pass

    def test_connect(self):
        """Test case for connect

        """
        pass

    def test_entity_ownership_info(self):
        """Test case for entity_ownership_info

        """
        pass

    def test_get_access_tokenfor_device(self):
        """Test case for get_access_tokenfor_device

        """
        pass

    def test_get_azure_token(self):
        """Test case for get_azure_token

        """
        pass

    def test_get_cloud_credentials(self):
        """Test case for get_cloud_credentials

        """
        pass

    def test_get_cloud_settings(self):
        """Test case for get_cloud_settings

        """
        pass

    def test_get_device_code(self):
        """Test case for get_device_code

        """
        pass

    def test_get_otp(self):
        """Test case for get_otp

        """
        pass

    def test_get_telemetry_state(self):
        """Test case for get_telemetry_state

        """
        pass

    def test_is_staging(self):
        """Test case for is_staging

        """
        pass

    def test_list_entity_ownership_info(self):
        """Test case for list_entity_ownership_info

        """
        pass

    def test_opt_in(self):
        """Test case for opt_in

        """
        pass

    def test_opt_out(self):
        """Test case for opt_out

        """
        pass

    def test_updatet_otp(self):
        """Test case for updatet_otp

        """
        pass


if __name__ == '__main__':
    unittest.main()
