"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_policy_supervisory_disc_list_builder_api import ConfigurationPolicySupervisoryDiscListBuilderApi  # noqa: E501


class TestConfigurationPolicySupervisoryDiscListBuilderApi(unittest.TestCase):
    """ConfigurationPolicySupervisoryDiscListBuilderApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationPolicySupervisoryDiscListBuilderApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_policy_list32(self):
        """Test case for create_policy_list32

        """
        pass

    def test_delete_policy_list32(self):
        """Test case for delete_policy_list32

        """
        pass

    def test_delete_policy_lists_with_info_tag32(self):
        """Test case for delete_policy_lists_with_info_tag32

        """
        pass

    def test_edit_policy_list32(self):
        """Test case for edit_policy_list32

        """
        pass

    def test_get_lists_by_id32(self):
        """Test case for get_lists_by_id32

        """
        pass

    def test_get_policy_lists29(self):
        """Test case for get_policy_lists29

        """
        pass

    def test_get_policy_lists_with_info_tag32(self):
        """Test case for get_policy_lists_with_info_tag32

        """
        pass

    def test_preview_policy_list32(self):
        """Test case for preview_policy_list32

        """
        pass

    def test_preview_policy_list_by_id32(self):
        """Test case for preview_policy_list_by_id32

        """
        pass


if __name__ == '__main__':
    unittest.main()
