"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.colocation_cluster_api import ColocationClusterApi  # noqa: E501


class TestColocationClusterApi(unittest.TestCase):
    """ColocationClusterApi unit test stubs"""

    def setUp(self):
        self.api = ColocationClusterApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acitvate_cloud_dock_cluster(self):
        """Test case for acitvate_cloud_dock_cluster

        """
        pass

    def test_cloud_dock_cluster_preview(self):
        """Test case for cloud_dock_cluster_preview

        """
        pass

    def test_create_cloud_dock_cluster(self):
        """Test case for create_cloud_dock_cluster

        """
        pass

    def test_de_acitvate_cloud_dock_cluster(self):
        """Test case for de_acitvate_cloud_dock_cluster

        """
        pass

    def test_delete_cloud_dock_cluster_by_name(self):
        """Test case for delete_cloud_dock_cluster_by_name

        """
        pass

    def test_dummyccm(self):
        """Test case for dummyccm

        """
        pass

    def test_dummycsp_state(self):
        """Test case for dummycsp_state

        """
        pass

    def test_get_cloud_dock_cluster_detail(self):
        """Test case for get_cloud_dock_cluster_detail

        """
        pass

    def test_get_cloud_dock_cluster_detail_by_id(self):
        """Test case for get_cloud_dock_cluster_detail_by_id

        """
        pass

    def test_rma_cloud_dock_csp(self):
        """Test case for rma_cloud_dock_csp

        """
        pass

    def test_update_cloud_dock_cluster(self):
        """Test case for update_cloud_dock_cluster

        """
        pass

    def test_update_csp_to_cluster(self):
        """Test case for update_csp_to_cluster

        """
        pass


if __name__ == '__main__':
    unittest.main()
