"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_stats_processing_api import MonitoringStatsProcessingApi  # noqa: E501


class TestMonitoringStatsProcessingApi(unittest.TestCase):
    """MonitoringStatsProcessingApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringStatsProcessingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_enable_statistics_demo_mode(self):
        """Test case for enable_statistics_demo_mode

        """
        pass

    def test_generate_stats_collect_thread_report(self):
        """Test case for generate_stats_collect_thread_report

        """
        pass

    def test_generate_stats_process_report(self):
        """Test case for generate_stats_process_report

        """
        pass

    def test_generate_stats_process_thread_report(self):
        """Test case for generate_stats_process_thread_report

        """
        pass

    def test_get_statistic_type(self):
        """Test case for get_statistic_type

        """
        pass

    def test_get_statistics_processing_counters(self):
        """Test case for get_statistics_processing_counters

        """
        pass

    def test_process_statistics_data(self):
        """Test case for process_statistics_data

        """
        pass

    def test_reset_stats_collection(self):
        """Test case for reset_stats_collection

        """
        pass

    def test_start_stats_collection(self):
        """Test case for start_stats_collection

        """
        pass


if __name__ == '__main__':
    unittest.main()
