"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_general_template_api import ConfigurationGeneralTemplateApi  # noqa: E501


class TestConfigurationGeneralTemplateApi(unittest.TestCase):
    """ConfigurationGeneralTemplateApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationGeneralTemplateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_template_resource_group(self):
        """Test case for change_template_resource_group

        """
        pass

    def test_clone_template(self):
        """Test case for clone_template

        """
        pass

    def test_create_feature_template(self):
        """Test case for create_feature_template

        """
        pass

    def test_create_li_template(self):
        """Test case for create_li_template

        """
        pass

    def test_delete_general_template(self):
        """Test case for delete_general_template

        """
        pass

    def test_edit_feature_template(self):
        """Test case for edit_feature_template

        """
        pass

    def test_edit_li_template(self):
        """Test case for edit_li_template

        """
        pass

    def test_generate_feature_template_list(self):
        """Test case for generate_feature_template_list

        """
        pass

    def test_generate_master_template_definition(self):
        """Test case for generate_master_template_definition

        """
        pass

    def test_generate_template_by_device_type(self):
        """Test case for generate_template_by_device_type

        """
        pass

    def test_generate_template_type_definition(self):
        """Test case for generate_template_type_definition

        """
        pass

    def test_generate_template_types(self):
        """Test case for generate_template_types

        """
        pass

    def test_get_default_networks(self):
        """Test case for get_default_networks

        """
        pass

    def test_get_device_templates_attached_to_feature(self):
        """Test case for get_device_templates_attached_to_feature

        """
        pass

    def test_get_encrypted_string(self):
        """Test case for get_encrypted_string

        """
        pass

    def test_get_general_template(self):
        """Test case for get_general_template

        """
        pass

    def test_get_network_interface(self):
        """Test case for get_network_interface

        """
        pass

    def test_get_template_definition(self):
        """Test case for get_template_definition

        """
        pass

    def test_get_template_for_migration(self):
        """Test case for get_template_for_migration

        """
        pass

    def test_list_li_template(self):
        """Test case for list_li_template

        """
        pass


if __name__ == '__main__':
    unittest.main()
