"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_system_status_stats_api import MonitoringSystemStatusStatsApi  # noqa: E501


class TestMonitoringSystemStatusStatsApi(unittest.TestCase):
    """MonitoringSystemStatusStatsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringSystemStatusStatsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_by_query17(self):
        """Test case for get_aggregation_data_by_query17

        """
        pass

    def test_get_count19(self):
        """Test case for get_count19

        """
        pass

    def test_get_count_post19(self):
        """Test case for get_count_post19

        """
        pass

    def test_get_post_aggregation_app_data_by_query16(self):
        """Test case for get_post_aggregation_app_data_by_query16

        """
        pass

    def test_get_post_aggregation_data_by_query16(self):
        """Test case for get_post_aggregation_data_by_query16

        """
        pass

    def test_get_post_stat_bulk_raw_data17(self):
        """Test case for get_post_stat_bulk_raw_data17

        """
        pass

    def test_get_stat_bulk_raw_data17(self):
        """Test case for get_stat_bulk_raw_data17

        """
        pass

    def test_get_stat_data_fields19(self):
        """Test case for get_stat_data_fields19

        """
        pass

    def test_get_stat_data_raw_data16(self):
        """Test case for get_stat_data_raw_data16

        """
        pass

    def test_get_stat_data_raw_data_as_csv17(self):
        """Test case for get_stat_data_raw_data_as_csv17

        """
        pass

    def test_get_stat_query_fields19(self):
        """Test case for get_stat_query_fields19

        """
        pass

    def test_get_stats_raw_data17(self):
        """Test case for get_stats_raw_data17

        """
        pass


if __name__ == '__main__':
    unittest.main()
