"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_device_details_api import MonitoringDeviceDetailsApi  # noqa: E501


class TestMonitoringDeviceDetailsApi(unittest.TestCase):
    """MonitoringDeviceDetailsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringDeviceDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_enable_sdavcon_device(self):
        """Test case for enable_sdavcon_device

        """
        pass

    def test_generate_device_state_data(self):
        """Test case for generate_device_state_data

        """
        pass

    def test_generate_device_state_data_fields(self):
        """Test case for generate_device_state_data_fields

        """
        pass

    def test_generate_device_state_data_with_query_string(self):
        """Test case for generate_device_state_data_with_query_string

        """
        pass

    def test_get_all_device_status(self):
        """Test case for get_all_device_status

        """
        pass

    def test_get_device_counters(self):
        """Test case for get_device_counters

        """
        pass

    def test_get_device_list_as_key_value(self):
        """Test case for get_device_list_as_key_value

        """
        pass

    def test_get_device_models(self):
        """Test case for get_device_models

        """
        pass

    def test_get_device_only_status(self):
        """Test case for get_device_only_status

        """
        pass

    def test_get_device_running_config(self):
        """Test case for get_device_running_config

        """
        pass

    def test_get_device_running_config_html(self):
        """Test case for get_device_running_config_html

        """
        pass

    def test_get_device_tloc_status(self):
        """Test case for get_device_tloc_status

        """
        pass

    def test_get_device_tloc_util(self):
        """Test case for get_device_tloc_util

        """
        pass

    def test_get_device_tloc_util_details(self):
        """Test case for get_device_tloc_util_details

        """
        pass

    def test_get_hardware_health_details(self):
        """Test case for get_hardware_health_details

        """
        pass

    def test_get_hardware_health_summary(self):
        """Test case for get_hardware_health_summary

        """
        pass

    def test_get_stats_queues(self):
        """Test case for get_stats_queues

        """
        pass

    def test_get_sync_queues(self):
        """Test case for get_sync_queues

        """
        pass

    def test_get_unconfigured(self):
        """Test case for get_unconfigured

        """
        pass

    def test_get_v_manage_system_ip(self):
        """Test case for get_v_manage_system_ip

        """
        pass

    def test_get_vedge_inventory(self):
        """Test case for get_vedge_inventory

        """
        pass

    def test_get_vedge_inventory_summary(self):
        """Test case for get_vedge_inventory_summary

        """
        pass

    def test_list_all_device_models(self):
        """Test case for list_all_device_models

        """
        pass

    def test_list_all_devices(self):
        """Test case for list_all_devices

        """
        pass

    def test_list_all_monitor_details_devices(self):
        """Test case for list_all_monitor_details_devices

        """
        pass

    def test_list_currently_syncing_devices(self):
        """Test case for list_currently_syncing_devices

        """
        pass

    def test_list_reachable_devices(self):
        """Test case for list_reachable_devices

        """
        pass

    def test_list_unreachable_devices(self):
        """Test case for list_unreachable_devices

        """
        pass

    def test_remove_unreachable_device(self):
        """Test case for remove_unreachable_device

        """
        pass

    def test_set_block_sync(self):
        """Test case for set_block_sync

        """
        pass

    def test_sync_all_devices_mem_db(self):
        """Test case for sync_all_devices_mem_db

        """
        pass


if __name__ == '__main__':
    unittest.main()
