"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_feature_profile_sdwan_api import ConfigurationFeatureProfileSDWANApi  # noqa: E501


class TestConfigurationFeatureProfileSDWANApi(unittest.TestCase):
    """ConfigurationFeatureProfileSDWANApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationFeatureProfileSDWANApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_aaa_profile_parcel_for_system(self):
        """Test case for create_aaa_profile_parcel_for_system

        """
        pass

    def test_create_banner_profile_parcel_for_system(self):
        """Test case for create_banner_profile_parcel_for_system

        """
        pass

    def test_create_basic_profile_parcel_for_system(self):
        """Test case for create_basic_profile_parcel_for_system

        """
        pass

    def test_create_bfd_profile_parcel_for_system(self):
        """Test case for create_bfd_profile_parcel_for_system

        """
        pass

    def test_create_cellular_controller_and_cellular_profile_parcel_association_for_transport(self):
        """Test case for create_cellular_controller_and_cellular_profile_parcel_association_for_transport

        """
        pass

    def test_create_cellular_controller_profile_parcel_for_transport(self):
        """Test case for create_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_create_cellular_profile_profile_parcel_for_transport(self):
        """Test case for create_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_create_global_profile_parcel_for_system(self):
        """Test case for create_global_profile_parcel_for_system

        """
        pass

    def test_create_lan_vpn_and_routing_bgp_parcel_association_for_service(self):
        """Test case for create_lan_vpn_and_routing_bgp_parcel_association_for_service

        """
        pass

    def test_create_lan_vpn_and_routing_ospf_parcel_association_for_service(self):
        """Test case for create_lan_vpn_and_routing_ospf_parcel_association_for_service

        """
        pass

    def test_create_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for create_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_create_lan_vpn_interface_ethernet_parcel_for_service(self):
        """Test case for create_lan_vpn_interface_ethernet_parcel_for_service

        """
        pass

    def test_create_lan_vpn_profile_parcel_for_service(self):
        """Test case for create_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_create_logging_profile_parcel_for_system(self):
        """Test case for create_logging_profile_parcel_for_system

        """
        pass

    def test_create_management_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for create_management_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_create_management_vpn_profile_parcel_for_transport(self):
        """Test case for create_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_create_ntp_profile_parcel_for_system(self):
        """Test case for create_ntp_profile_parcel_for_system

        """
        pass

    def test_create_omp_profile_parcel_for_system(self):
        """Test case for create_omp_profile_parcel_for_system

        """
        pass

    def test_create_routing_bgp_profile_parcel_for_service(self):
        """Test case for create_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_create_routing_ospf_profile_parcel_for_service(self):
        """Test case for create_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_create_sdwan_config_profile_parcel_for_cli(self):
        """Test case for create_sdwan_config_profile_parcel_for_cli

        """
        pass

    def test_create_sdwan_feature_profile(self):
        """Test case for create_sdwan_feature_profile

        """
        pass

    def test_create_sdwan_service_feature_profile(self):
        """Test case for create_sdwan_service_feature_profile

        """
        pass

    def test_create_sdwan_system_feature_profile(self):
        """Test case for create_sdwan_system_feature_profile

        """
        pass

    def test_create_sdwan_transport_feature_profile(self):
        """Test case for create_sdwan_transport_feature_profile

        """
        pass

    def test_create_tracker_profile_parcel_for_service(self):
        """Test case for create_tracker_profile_parcel_for_service

        """
        pass

    def test_create_tracker_profile_parcel_for_transport(self):
        """Test case for create_tracker_profile_parcel_for_transport

        """
        pass

    def test_create_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for create_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_create_wan_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for create_wan_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_create_wan_vpn_profile_parcel_for_transport(self):
        """Test case for create_wan_vpn_profile_parcel_for_transport

        """
        pass

    def test_delete_aaa_profile_parcel_for_system(self):
        """Test case for delete_aaa_profile_parcel_for_system

        """
        pass

    def test_delete_banner_profile_parcel_for_system(self):
        """Test case for delete_banner_profile_parcel_for_system

        """
        pass

    def test_delete_basic_profile_parcel_for_system(self):
        """Test case for delete_basic_profile_parcel_for_system

        """
        pass

    def test_delete_bfd_profile_parcel_for_system(self):
        """Test case for delete_bfd_profile_parcel_for_system

        """
        pass

    def test_delete_cellular_controller_and_cellular_profile_association_for_transport(self):
        """Test case for delete_cellular_controller_and_cellular_profile_association_for_transport

        """
        pass

    def test_delete_cellular_controller_profile_parcel_for_transport(self):
        """Test case for delete_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_delete_cellular_profile_profile_parcel_for_transport(self):
        """Test case for delete_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_delete_config_profile_parcel_for_cli(self):
        """Test case for delete_config_profile_parcel_for_cli

        """
        pass

    def test_delete_global_profile_parcel_for_system(self):
        """Test case for delete_global_profile_parcel_for_system

        """
        pass

    def test_delete_lan_vpn_and_routing_bgp_association_for_service(self):
        """Test case for delete_lan_vpn_and_routing_bgp_association_for_service

        """
        pass

    def test_delete_lan_vpn_and_routing_ospf_association_for_service(self):
        """Test case for delete_lan_vpn_and_routing_ospf_association_for_service

        """
        pass

    def test_delete_lan_vpn_interface_ethernet_and_tracker_association_for_transport(self):
        """Test case for delete_lan_vpn_interface_ethernet_and_tracker_association_for_transport

        """
        pass

    def test_delete_lan_vpn_interface_ethernet_for_service(self):
        """Test case for delete_lan_vpn_interface_ethernet_for_service

        """
        pass

    def test_delete_lan_vpn_profile_parcel_for_service(self):
        """Test case for delete_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_delete_logging_profile_parcel_for_system(self):
        """Test case for delete_logging_profile_parcel_for_system

        """
        pass

    def test_delete_management_vpn_interface_ethernet_for_transport(self):
        """Test case for delete_management_vpn_interface_ethernet_for_transport

        """
        pass

    def test_delete_management_vpn_profile_parcel_for_transport(self):
        """Test case for delete_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_delete_ntp_profile_parcel_for_system(self):
        """Test case for delete_ntp_profile_parcel_for_system

        """
        pass

    def test_delete_omp_profile_parcel_for_system(self):
        """Test case for delete_omp_profile_parcel_for_system

        """
        pass

    def test_delete_routing_bgp_profile_parcel_for_service(self):
        """Test case for delete_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_delete_routing_ospf_profile_parcel_for_service(self):
        """Test case for delete_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_delete_sdwan_feature_profile_for_cli(self):
        """Test case for delete_sdwan_feature_profile_for_cli

        """
        pass

    def test_delete_sdwan_service_feature_profile(self):
        """Test case for delete_sdwan_service_feature_profile

        """
        pass

    def test_delete_sdwan_system_feature_profile(self):
        """Test case for delete_sdwan_system_feature_profile

        """
        pass

    def test_delete_sdwan_transport_feature_profile(self):
        """Test case for delete_sdwan_transport_feature_profile

        """
        pass

    def test_delete_tracker_profile_parcel_for_service(self):
        """Test case for delete_tracker_profile_parcel_for_service

        """
        pass

    def test_delete_tracker_profile_parcel_for_transport(self):
        """Test case for delete_tracker_profile_parcel_for_transport

        """
        pass

    def test_delete_wan_vpn_interface_ethernet_and_tracker_association_for_transport(self):
        """Test case for delete_wan_vpn_interface_ethernet_and_tracker_association_for_transport

        """
        pass

    def test_delete_wan_vpn_interface_ethernet_for_transport(self):
        """Test case for delete_wan_vpn_interface_ethernet_for_transport

        """
        pass

    def test_delete_wan_vpn_profile_parcel_for_transport(self):
        """Test case for delete_wan_vpn_profile_parcel_for_transport

        """
        pass

    def test_edit_aaa_profile_parcel_for_system(self):
        """Test case for edit_aaa_profile_parcel_for_system

        """
        pass

    def test_edit_banner_profile_parcel_for_system(self):
        """Test case for edit_banner_profile_parcel_for_system

        """
        pass

    def test_edit_basic_profile_parcel_for_system(self):
        """Test case for edit_basic_profile_parcel_for_system

        """
        pass

    def test_edit_bfd_profile_parcel_for_system(self):
        """Test case for edit_bfd_profile_parcel_for_system

        """
        pass

    def test_edit_cellular_controller_and_cellular_profile_parcel_association_for_transport(self):
        """Test case for edit_cellular_controller_and_cellular_profile_parcel_association_for_transport

        """
        pass

    def test_edit_cellular_controller_profile_parcel_for_transport(self):
        """Test case for edit_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_edit_cellular_profile_profile_parcel_for_transport(self):
        """Test case for edit_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_edit_config_profile_parcel_for_cli(self):
        """Test case for edit_config_profile_parcel_for_cli

        """
        pass

    def test_edit_global_profile_parcel_for_system(self):
        """Test case for edit_global_profile_parcel_for_system

        """
        pass

    def test_edit_lan_vpn_and_routing_bgp_parcel_association_for_service(self):
        """Test case for edit_lan_vpn_and_routing_bgp_parcel_association_for_service

        """
        pass

    def test_edit_lan_vpn_and_routing_ospf_parcel_association_for_service(self):
        """Test case for edit_lan_vpn_and_routing_ospf_parcel_association_for_service

        """
        pass

    def test_edit_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for edit_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_edit_lan_vpn_interface_ethernet_parcel_for_service(self):
        """Test case for edit_lan_vpn_interface_ethernet_parcel_for_service

        """
        pass

    def test_edit_lan_vpn_profile_parcel_for_service(self):
        """Test case for edit_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_edit_logging_profile_parcel_for_system(self):
        """Test case for edit_logging_profile_parcel_for_system

        """
        pass

    def test_edit_management_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for edit_management_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_edit_management_vpn_profile_parcel_for_transport(self):
        """Test case for edit_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_edit_ntp_profile_parcel_for_system(self):
        """Test case for edit_ntp_profile_parcel_for_system

        """
        pass

    def test_edit_omp_profile_parcel_for_system(self):
        """Test case for edit_omp_profile_parcel_for_system

        """
        pass

    def test_edit_routing_bgp_profile_parcel_for_service(self):
        """Test case for edit_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_edit_routing_ospf_profile_parcel_for_service(self):
        """Test case for edit_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_edit_sdwan_feature_profile(self):
        """Test case for edit_sdwan_feature_profile

        """
        pass

    def test_edit_sdwan_service_feature_profile(self):
        """Test case for edit_sdwan_service_feature_profile

        """
        pass

    def test_edit_sdwan_system_feature_profile(self):
        """Test case for edit_sdwan_system_feature_profile

        """
        pass

    def test_edit_sdwan_transport_feature_profile(self):
        """Test case for edit_sdwan_transport_feature_profile

        """
        pass

    def test_edit_tracker_profile_parcel_for_service(self):
        """Test case for edit_tracker_profile_parcel_for_service

        """
        pass

    def test_edit_tracker_profile_parcel_for_transport(self):
        """Test case for edit_tracker_profile_parcel_for_transport

        """
        pass

    def test_edit_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for edit_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_edit_wan_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for edit_wan_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_edit_wan_vpn_profile_parcel_for_transport(self):
        """Test case for edit_wan_vpn_profile_parcel_for_transport

        """
        pass

    def test_get_aaa_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_aaa_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_aaa_profile_parcel_for_system(self):
        """Test case for get_aaa_profile_parcel_for_system

        """
        pass

    def test_get_banner_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_banner_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_banner_profile_parcel_for_system(self):
        """Test case for get_banner_profile_parcel_for_system

        """
        pass

    def test_get_basic_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_basic_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_basic_profile_parcel_for_system(self):
        """Test case for get_basic_profile_parcel_for_system

        """
        pass

    def test_get_bfd_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_bfd_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_bfd_profile_parcel_for_system(self):
        """Test case for get_bfd_profile_parcel_for_system

        """
        pass

    def test_get_cedge_system_global_parcel_schema_by_schema_type(self):
        """Test case for get_cedge_system_global_parcel_schema_by_schema_type

        """
        pass

    def test_get_cellular_controller_associated_cellular_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_cellular_controller_associated_cellular_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_cellular_controller_associated_cellular_profile_parcels_for_transport(self):
        """Test case for get_cellular_controller_associated_cellular_profile_parcels_for_transport

        """
        pass

    def test_get_cellular_controller_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_cellular_controller_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_cellular_controller_profile_parcel_for_transport(self):
        """Test case for get_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_get_cellular_profile_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_cellular_profile_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_cellular_profile_profile_parcel_for_transport(self):
        """Test case for get_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_get_config_profile_parcel_by_parcel_id_for_cli(self):
        """Test case for get_config_profile_parcel_by_parcel_id_for_cli

        """
        pass

    def test_get_config_profile_parcel_for_cli(self):
        """Test case for get_config_profile_parcel_for_cli

        """
        pass

    def test_get_global_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_global_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_global_profile_parcel_for_system(self):
        """Test case for get_global_profile_parcel_for_system

        """
        pass

    def test_get_interface_ethernet_parcels_for_service_lan_vpn(self):
        """Test case for get_interface_ethernet_parcels_for_service_lan_vpn

        """
        pass

    def test_get_interface_ethernet_parcels_for_transport_management_vpn(self):
        """Test case for get_interface_ethernet_parcels_for_transport_management_vpn

        """
        pass

    def test_get_interface_ethernet_parcels_for_transport_wan_vpn(self):
        """Test case for get_interface_ethernet_parcels_for_transport_wan_vpn

        """
        pass

    def test_get_lan_vpn_associated_routing_bgp_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_associated_routing_bgp_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_associated_routing_bgp_parcels_for_service(self):
        """Test case for get_lan_vpn_associated_routing_bgp_parcels_for_service

        """
        pass

    def test_get_lan_vpn_associated_routing_ospf_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_associated_routing_ospf_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_associated_routing_ospf_parcels_for_service(self):
        """Test case for get_lan_vpn_associated_routing_ospf_parcels_for_service

        """
        pass

    def test_get_lan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport(self):
        """Test case for get_lan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_lan_vpn_interface_ethernet_associated_tracker_parcels_for_transport(self):
        """Test case for get_lan_vpn_interface_ethernet_associated_tracker_parcels_for_transport

        """
        pass

    def test_get_lan_vpn_interface_ethernet_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_interface_ethernet_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_profile_parcel_for_service(self):
        """Test case for get_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_get_logging_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_logging_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_logging_profile_parcel_for_system(self):
        """Test case for get_logging_profile_parcel_for_system

        """
        pass

    def test_get_management_vpn_interface_ethernet_parcel_by_parcel_id_for_transport(self):
        """Test case for get_management_vpn_interface_ethernet_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_management_vpn_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_management_vpn_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_management_vpn_profile_parcel_for_transport(self):
        """Test case for get_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_get_ntp_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_ntp_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_ntp_profile_parcel_for_system(self):
        """Test case for get_ntp_profile_parcel_for_system

        """
        pass

    def test_get_omp_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_omp_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_omp_profile_parcel_for_system(self):
        """Test case for get_omp_profile_parcel_for_system

        """
        pass

    def test_get_routing_bgp_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_routing_bgp_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_routing_bgp_profile_parcel_for_service(self):
        """Test case for get_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_get_routing_ospf_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_routing_ospf_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_routing_ospf_profile_parcel_for_service(self):
        """Test case for get_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_get_sdwan_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_feature_profile_by_sdwan_family(self):
        """Test case for get_sdwan_feature_profile_by_sdwan_family

        """
        pass

    def test_get_sdwan_feature_profiles_by_family_and_type(self):
        """Test case for get_sdwan_feature_profiles_by_family_and_type

        """
        pass

    def test_get_sdwan_service_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_service_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_service_feature_profiles(self):
        """Test case for get_sdwan_service_feature_profiles

        """
        pass

    def test_get_sdwan_service_lan_vpn_interface_ethernet_parcel_schema_by_schema(self):
        """Test case for get_sdwan_service_lan_vpn_interface_ethernet_parcel_schema_by_schema

        """
        pass

    def test_get_sdwan_service_lan_vpn_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_lan_vpn_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_service_routing_bgp_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_routing_bgp_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_service_routing_ospf_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_routing_ospf_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_service_tracker_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_tracker_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_aaa_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_aaa_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_banner_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_banner_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_basic_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_basic_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_bfd_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_bfd_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_system_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_system_feature_profiles(self):
        """Test case for get_sdwan_system_feature_profiles

        """
        pass

    def test_get_sdwan_system_logging_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_logging_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_ntp_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_ntp_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_omp_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_omp_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_cellular_controller_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_cellular_controller_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_cellular_profile_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_cellular_profile_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_transport_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_transport_feature_profiles(self):
        """Test case for get_sdwan_transport_feature_profiles

        """
        pass

    def test_get_sdwan_transport_management_vpn_interface_ethernet_parcel_schema_by_schema(self):
        """Test case for get_sdwan_transport_management_vpn_interface_ethernet_parcel_schema_by_schema

        """
        pass

    def test_get_sdwan_transport_management_vpn_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_management_vpn_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_tracker_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_tracker_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_wan_vpn_interface_ethernet_parcel_schema_by_schema(self):
        """Test case for get_sdwan_transport_wan_vpn_interface_ethernet_parcel_schema_by_schema

        """
        pass

    def test_get_sdwan_transport_wan_vpn_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_wan_vpn_parcel_schema_by_schema_type

        """
        pass

    def test_get_tracker_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_tracker_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_tracker_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_tracker_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_tracker_profile_parcel_for_service(self):
        """Test case for get_tracker_profile_parcel_for_service

        """
        pass

    def test_get_tracker_profile_parcel_for_transport(self):
        """Test case for get_tracker_profile_parcel_for_transport

        """
        pass

    def test_get_wan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport(self):
        """Test case for get_wan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_wan_vpn_interface_ethernet_associated_tracker_parcels_for_transport(self):
        """Test case for get_wan_vpn_interface_ethernet_associated_tracker_parcels_for_transport

        """
        pass

    def test_get_wan_vpn_interface_ethernet_parcel_by_parcel_id_for_transport(self):
        """Test case for get_wan_vpn_interface_ethernet_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_wan_vpn_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_wan_vpn_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_wan_vpn_profile_parcel_for_transport(self):
        """Test case for get_wan_vpn_profile_parcel_for_transport

        """
        pass


if __name__ == '__main__':
    unittest.main()
