"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_azure_connect_api import ConfigurationAzureConnectApi  # noqa: E501


class TestConfigurationAzureConnectApi(unittest.TestCase):
    """ConfigurationAzureConnectApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationAzureConnectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authenticate_azure_connect_cred_and_add(self):
        """Test case for authenticate_azure_connect_cred_and_add

        """
        pass

    def test_delete_wan_resource_groups(self):
        """Test case for delete_wan_resource_groups

        """
        pass

    def test_edit_wan_resource_groups(self):
        """Test case for edit_wan_resource_groups

        """
        pass

    def test_get_cortex_status(self):
        """Test case for get_cortex_status

        """
        pass

    def test_get_mapped_wan_resource_groups(self):
        """Test case for get_mapped_wan_resource_groups

        """
        pass

    def test_get_wan_resource_groups(self):
        """Test case for get_wan_resource_groups

        """
        pass

    def test_save_wan_resource_groups(self):
        """Test case for save_wan_resource_groups

        """
        pass

    def test_sync_wan_resource_groups(self):
        """Test case for sync_wan_resource_groups

        """
        pass


if __name__ == '__main__':
    unittest.main()
