"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_endpoint_tracker_group_service_api import RealTimeMonitoringEndpointTrackerGroupServiceApi  # noqa: E501


class TestRealTimeMonitoringEndpointTrackerGroupServiceApi(unittest.TestCase):
    """RealTimeMonitoringEndpointTrackerGroupServiceApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringEndpointTrackerGroupServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_endpoint_tracker_group_info(self):
        """Test case for get_endpoint_tracker_group_info

        """
        pass


if __name__ == '__main__':
    unittest.main()
