"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_config_history_api import ConfigurationDeviceConfigHistoryApi  # noqa: E501


class TestConfigurationDeviceConfigHistoryApi(unittest.TestCase):
    """ConfigurationDeviceConfigHistoryApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceConfigHistoryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_by_query20(self):
        """Test case for get_aggregation_data_by_query20

        """
        pass

    def test_get_config_diff(self):
        """Test case for get_config_diff

        """
        pass

    def test_get_count22(self):
        """Test case for get_count22

        """
        pass

    def test_get_count_post22(self):
        """Test case for get_count_post22

        """
        pass

    def test_get_device_config(self):
        """Test case for get_device_config

        """
        pass

    def test_get_last_thousand_config_list(self):
        """Test case for get_last_thousand_config_list

        """
        pass

    def test_get_post_aggregation_app_data_by_query19(self):
        """Test case for get_post_aggregation_app_data_by_query19

        """
        pass

    def test_get_post_aggregation_data_by_query19(self):
        """Test case for get_post_aggregation_data_by_query19

        """
        pass

    def test_get_post_stat_bulk_raw_data20(self):
        """Test case for get_post_stat_bulk_raw_data20

        """
        pass

    def test_get_stat_bulk_raw_data20(self):
        """Test case for get_stat_bulk_raw_data20

        """
        pass

    def test_get_stat_data_fields22(self):
        """Test case for get_stat_data_fields22

        """
        pass

    def test_get_stat_data_raw_data19(self):
        """Test case for get_stat_data_raw_data19

        """
        pass

    def test_get_stat_data_raw_data_as_csv20(self):
        """Test case for get_stat_data_raw_data_as_csv20

        """
        pass

    def test_get_stat_query_fields22(self):
        """Test case for get_stat_query_fields22

        """
        pass

    def test_get_stats_raw_data20(self):
        """Test case for get_stats_raw_data20

        """
        pass


if __name__ == '__main__':
    unittest.main()
