"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_voice_api import RealTimeMonitoringVoiceApi  # noqa: E501


class TestRealTimeMonitoringVoiceApi(unittest.TestCase):
    """RealTimeMonitoringVoiceApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringVoiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_controller_t1e1_info_current15_min_stats(self):
        """Test case for get_controller_t1e1_info_current15_min_stats

        """
        pass

    def test_get_controller_t1e1_info_total_stats(self):
        """Test case for get_controller_t1e1_info_total_stats

        """
        pass

    def test_get_dsp_active(self):
        """Test case for get_dsp_active

        """
        pass

    def test_get_dsp_farm_profiles(self):
        """Test case for get_dsp_farm_profiles

        """
        pass

    def test_get_phone_info(self):
        """Test case for get_phone_info

        """
        pass

    def test_get_sccp_ccm_groups(self):
        """Test case for get_sccp_ccm_groups

        """
        pass

    def test_get_sccp_connections(self):
        """Test case for get_sccp_connections

        """
        pass

    def test_get_t1e1_isdn_status(self):
        """Test case for get_t1e1_isdn_status

        """
        pass

    def test_get_voice_calls(self):
        """Test case for get_voice_calls

        """
        pass

    def test_get_voip_calls(self):
        """Test case for get_voip_calls

        """
        pass


if __name__ == '__main__':
    unittest.main()
