"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_interface_api import RealTimeMonitoringInterfaceApi  # noqa: E501


class TestRealTimeMonitoringInterfaceApi(unittest.TestCase):
    """RealTimeMonitoringInterfaceApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringInterfaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_device_interface_vpn(self):
        """Test case for generate_device_interface_vpn

        """
        pass

    def test_get_device_interface(self):
        """Test case for get_device_interface

        """
        pass

    def test_get_device_interface_arp_stats(self):
        """Test case for get_device_interface_arp_stats

        """
        pass

    def test_get_device_interface_error_stats(self):
        """Test case for get_device_interface_error_stats

        """
        pass

    def test_get_device_interface_ipv6_stats(self):
        """Test case for get_device_interface_ipv6_stats

        """
        pass

    def test_get_device_interface_pkt_sizes(self):
        """Test case for get_device_interface_pkt_sizes

        """
        pass

    def test_get_device_interface_port_stats(self):
        """Test case for get_device_interface_port_stats

        """
        pass

    def test_get_device_interface_qos_stats(self):
        """Test case for get_device_interface_qos_stats

        """
        pass

    def test_get_device_interface_queue_stats(self):
        """Test case for get_device_interface_queue_stats

        """
        pass

    def test_get_device_interface_stats(self):
        """Test case for get_device_interface_stats

        """
        pass

    def test_get_device_serial_interface(self):
        """Test case for get_device_serial_interface

        """
        pass

    def test_get_synced_device_interface(self):
        """Test case for get_synced_device_interface

        """
        pass

    def test_trustsec(self):
        """Test case for trustsec

        """
        pass


if __name__ == '__main__':
    unittest.main()
