"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_v_smart_template_policy_api import ConfigurationVSmartTemplatePolicyApi  # noqa: E501


class TestConfigurationVSmartTemplatePolicyApi(unittest.TestCase):
    """ConfigurationVSmartTemplatePolicyApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationVSmartTemplatePolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_policy(self):
        """Test case for activate_policy

        """
        pass

    def test_activate_policy_for_cloud_services(self):
        """Test case for activate_policy_for_cloud_services

        """
        pass

    def test_check_v_smart_connectivity_status(self):
        """Test case for check_v_smart_connectivity_status

        """
        pass

    def test_create_v_smart_template(self):
        """Test case for create_v_smart_template

        """
        pass

    def test_de_activate_policy(self):
        """Test case for de_activate_policy

        """
        pass

    def test_delete_v_smart_template(self):
        """Test case for delete_v_smart_template

        """
        pass

    def test_edit_template_without_lock_checks(self):
        """Test case for edit_template_without_lock_checks

        """
        pass

    def test_edit_v_smart_template(self):
        """Test case for edit_v_smart_template

        """
        pass

    def test_generate_v_smart_policy_template_list(self):
        """Test case for generate_v_smart_policy_template_list

        """
        pass

    def test_get_template_by_policy_id(self):
        """Test case for get_template_by_policy_id

        """
        pass

    def test_qosmos_nbar_migration_warning(self):
        """Test case for qosmos_nbar_migration_warning

        """
        pass


if __name__ == '__main__':
    unittest.main()
